@@ -35,8 +35,8 @@ class CloseToOverflowReward(BaseReward):
 
     """
 
-    def __init__(self, max_lines=5):
-        BaseReward.__init__(self)
+    def __init__(self, max_lines=5, logger=None):
+        BaseReward.__init__(self, logger=logger)
         self.reward_min = dt_float(0.0)
         self.reward_max = dt_float(1.0)
         self.max_overflowed = dt_float(max_lines)
