@@ -36,8 +36,8 @@ class GameplayReward(BaseReward):
 
     """
 
-    def __init__(self):
-        BaseReward.__init__(self)
+    def __init__(self, logger=None):
+        BaseReward.__init__(self, logger=logger)
         self.reward_min = dt_float(-1.0)
         self.reward_max = dt_float(1.0)
 
