@@ -1,8 +1,4 @@
-__all__ = [
-    "RandomObject",
-    "SerializableSpace",
-    "GridObjects"
-]
+__all__ = ["RandomObject", "SerializableSpace", "GridObjects"]
 
 from grid2op.Space.RandomObject import RandomObject
 from grid2op.Space.SerializableSpace import SerializableSpace
