@@ -15,26 +15,26 @@ config = {
     "grid_value_class": GridStateFromFileWithForecasts,
     "volagecontroler_class": None,
     "thermal_limits": [
-        3.84900179e+02,
-        3.84900179e+02,
-        2.28997102e+05,
-        2.28997102e+05,
-        2.28997102e+05,
-        1.52664735e+04,
-        2.28997102e+05,
-        3.84900179e+02,
-        3.84900179e+02,
-        1.83285800e+02,
-        3.84900179e+02,
-        3.84900179e+02,
-        2.28997102e+05,
-        2.28997102e+05,
-        6.93930612e+04,
-        3.84900179e+02,
-        3.84900179e+02,
-        2.40562612e+02,
-        3.40224266e+03,
-        3.40224266e+03
+        3.84900179e02,
+        3.84900179e02,
+        2.28997102e05,
+        2.28997102e05,
+        2.28997102e05,
+        1.52664735e04,
+        2.28997102e05,
+        3.84900179e02,
+        3.84900179e02,
+        1.83285800e02,
+        3.84900179e02,
+        3.84900179e02,
+        2.28997102e05,
+        2.28997102e05,
+        6.93930612e04,
+        3.84900179e02,
+        3.84900179e02,
+        2.40562612e02,
+        3.40224266e03,
+        3.40224266e03,
     ],
-    "names_chronics_to_grid": None
+    "names_chronics_to_grid": None,
 }
