@@ -7,6 +7,10 @@
 # This file is part of Grid2Op, Grid2Op a testbed platform to model sequential decision making in power systems.
 import numpy as np
 
-dt_int = np.int32  # dtype('int64') or dtype('int32') depending on platform => i force it to int32
-dt_float = np.float32    # dtype('float64') or dtype('float32') depending on platform  => i force it to float32
-dt_bool = np.bool
\ No newline at end of file
+dt_int = (
+    np.int32
+)  # dtype('int64') or dtype('int32') depending on platform => i force it to int32
+dt_float = (
+    np.float32
+)  # dtype('float64') or dtype('float32') depending on platform  => i force it to float32
+dt_bool = np.bool
