@@ -39,15 +39,14 @@ class MultiDiscreteActSpace(MultiDiscrete):
       or "CONNECT TO BUSBAR 2" and affecting to which busbar an object is connected
     - "change_bus": `dim_topo` dimensions, each containing 2 choices: "CHANGE", "DONT CHANGE" and affect
       to which busbar an element is connected
-    - "redispatch": `n_gen` dimensions, each containing a certain number of choices depending on the value
-      of the keyword argument `nb_bins["redispatch"]` (by default 7) and will be 1 for non dispatchable generator
-    - "curtail": `n_gen` dimensions, each containing a certain number of choices depending on the value
-      of the keyword argument `nb_bins["curtail"]` (by default 7) and will be 1 for non renewable generator. This is
+    - "redispatch": `sum(env.gen_redispatchable)` dimensions, each containing a certain number of choices depending on the value
+      of the keyword argument `nb_bins["redispatch"]` (by default 7).
+    - "curtail": `sum(env.gen_renewable)` dimensions, each containing a certain number of choices depending on the value
+      of the keyword argument `nb_bins["curtail"]` (by default 7). This is
       the "conversion to discrete action"
       of the curtailment action.
-    - "curtail_mw": completely equivalent to "curtail" for this representation. This is the "conversion to
-      discrete action"
-      of the curtailment action.
+    - "curtail_mw": `sum(env.gen_renewable)` dimensions, completely equivalent to "curtail" for this representation. 
+      This is the "conversion to discrete action" of the curtailment action.
     - "set_storage": `n_storage` dimensions, each containing a certain number of choices depending on the value
       of the keyword argument `nb_bins["set_storage"]` (by default 7). This is the "conversion to discrete action"
       of the action on storage units.
@@ -72,16 +71,16 @@ class MultiDiscreteActSpace(MultiDiscrete):
         "line_change_status", "one_sub_change" or "change_bus".
 
         Combining a "set" and "change" on the same element will most likely lead to an "ambiguous action". Indeed
-        what grid2op can do if you "tell element A to go to bus 1" and "tell element A2 to go to bus 2 if it was
-        to 1 and to move to bus 1 if it was on bus 2". It's not clear at all.
+        what grid2op can do if you "tell element A to go to bus 1" and "tell the same element A to switch to bus 2 if it was
+        to 1 and to move to bus 1 if it was on bus 2". It's not clear at all (hence the "ambiguous").
 
         No error will be thrown if you mix this, this is your absolute right, be aware it might not
         lead to the result you expect though.
 
-    .. warning::
+    .. note::
 
-        The arguments "set_bus", "sub_set_bus" and "one_sub_set" will all perform "set_bus" action. The only
-        difference if "how you represent this action":
+        The arguments "set_bus", "sub_set_bus" and "one_sub_set" will all perform "set_bus" actions. The only
+        difference if "how you represent these actions":
 
         - In "set_bus" each component represent a single element of the grid. When you sample an action
           with this keyword you will possibly change all the elements of the grid at once (this is likely to
@@ -140,21 +139,20 @@ class MultiDiscreteActSpace(MultiDiscrete):
     you can be in your control, but the higher the dimension of the action space.
 
     """
+
     ATTR_CHANGE = 0
     ATTR_SET = 1
     ATTR_NEEDBUILD = 2
     ATTR_NEEDBINARIZED = 3
 
-    def __init__(self,
-                 grid2op_action_space,
-                 attr_to_keep=ALL_ATTR,
-                 nb_bins=None
-                 ):
+    def __init__(self, grid2op_action_space, attr_to_keep=ALL_ATTR, nb_bins=None):
         check_gym_version()
         if not isinstance(grid2op_action_space, ActionSpace):
-            raise RuntimeError(f"Impossible to create a BoxGymActSpace without providing a "
-                               f"grid2op action_space. You provided {type(grid2op_action_space)}"
-                               f"as the \"grid2op_action_space\" attribute.")
+            raise RuntimeError(
+                f"Impossible to create a BoxGymActSpace without providing a "
+                f"grid2op action_space. You provided {type(grid2op_action_space)}"
+                f'as the "grid2op_action_space" attribute.'
+            )
 
         if nb_bins is None:
             nb_bins = {"redispatch": 7, "set_storage": 7, "curtail": 7, "curtail_mw": 7}
@@ -163,16 +161,19 @@ class MultiDiscreteActSpace(MultiDiscrete):
             # by default, i remove all the attributes that are not supported by the action type
             # i do not do that if the user specified specific attributes to keep. This is his responsibility in
             # in this case
-            attr_to_keep = {el for el in attr_to_keep if grid2op_action_space.supports_type(el)}
+            attr_to_keep = {
+                el for el in attr_to_keep if grid2op_action_space.supports_type(el)
+            }
 
         for el in attr_to_keep:
             if el not in ATTR_DISCRETE:
-                warnings.warn(f"The class \"MultiDiscreteActSpace\" should mainly be used to consider only discrete "
-                              f"actions (eg. set_line_status, set_bus or change_bus). Though it is possible to use "
-                              f"\"{el}\" when building it, be aware that this continuous action will be treated "
-                              f"as discrete by splitting it into bins. "
-                              f"Consider using the \"BoxGymActSpace\" for these attributes."
-                              )
+                warnings.warn(
+                    f'The class "MultiDiscreteActSpace" should mainly be used to consider only discrete '
+                    f"actions (eg. set_line_status, set_bus or change_bus). Though it is possible to use "
+                    f'"{el}" when building it, be aware that this continuous action will be treated '
+                    f"as discrete by splitting it into bins. "
+                    f'Consider using the "BoxGymActSpace" for these attributes.'
+                )
 
         self._attr_to_keep = sorted(attr_to_keep)
 
@@ -181,45 +182,89 @@ class MultiDiscreteActSpace(MultiDiscrete):
 
         low_gen = -1.0 * act_sp.gen_max_ramp_down
         high_gen = 1.0 * act_sp.gen_max_ramp_up
-        low_gen[~act_sp.gen_redispatchable] = 0.
-        high_gen[~act_sp.gen_redispatchable] = 0.
+        low_gen[~act_sp.gen_redispatchable] = 0.0
+        high_gen[~act_sp.gen_redispatchable] = 0.0
 
         # nb, dim, []
         self.dict_properties = {
-            "set_line_status": ([3 for _ in range(act_sp.n_line)],
-                                act_sp.n_line, self.ATTR_SET),
-            "change_line_status": ([2 for _ in range(act_sp.n_line)],
-                                   act_sp.n_line, self.ATTR_CHANGE),
-            "set_bus": ([4 for _ in range(act_sp.dim_topo)],
-                        act_sp.dim_topo, self.ATTR_SET),
-            "change_bus": ([2 for _ in range(act_sp.dim_topo)],
-                           act_sp.dim_topo, self.ATTR_CHANGE),
-            "raise_alarm": ([2 for _ in range(act_sp.dim_alarms)],
-                            act_sp.dim_alarms, self.ATTR_CHANGE),
-            "sub_set_bus": (None, act_sp.n_sub, self.ATTR_NEEDBUILD),  # dimension will be computed on the fly, if the stuff is used
-            "sub_change_bus": (None, act_sp.n_sub, self.ATTR_NEEDBUILD),  # dimension will be computed on the fly, if the stuff is used
-            "one_sub_set": (None, 1, self.ATTR_NEEDBUILD),  # dimension will be computed on the fly, if the stuff is used
-            "one_sub_change": (None, 1, self.ATTR_NEEDBUILD),  # dimension will be computed on the fly, if the stuff is used
+            "set_line_status": (
+                [3 for _ in range(act_sp.n_line)],
+                act_sp.n_line,
+                self.ATTR_SET,
+            ),
+            "change_line_status": (
+                [2 for _ in range(act_sp.n_line)],
+                act_sp.n_line,
+                self.ATTR_CHANGE,
+            ),
+            "set_bus": (
+                [4 for _ in range(act_sp.dim_topo)],
+                act_sp.dim_topo,
+                self.ATTR_SET,
+            ),
+            "change_bus": (
+                [2 for _ in range(act_sp.dim_topo)],
+                act_sp.dim_topo,
+                self.ATTR_CHANGE,
+            ),
+            "raise_alarm": (
+                [2 for _ in range(act_sp.dim_alarms)],
+                act_sp.dim_alarms,
+                self.ATTR_CHANGE,
+            ),
+            "sub_set_bus": (
+                None,
+                act_sp.n_sub,
+                self.ATTR_NEEDBUILD,
+            ),  # dimension will be computed on the fly, if the stuff is used
+            "sub_change_bus": (
+                None,
+                act_sp.n_sub,
+                self.ATTR_NEEDBUILD,
+            ),  # dimension will be computed on the fly, if the stuff is used
+            "one_sub_set": (
+                None,
+                1,
+                self.ATTR_NEEDBUILD,
+            ),  # dimension will be computed on the fly, if the stuff is used
+            "one_sub_change": (
+                None,
+                1,
+                self.ATTR_NEEDBUILD,
+            ),  # dimension will be computed on the fly, if the stuff is used
         }
         self._nb_bins = nb_bins
         for el in ["redispatch", "set_storage", "curtail", "curtail_mw"]:
             if el in attr_to_keep:
                 if el not in nb_bins:
-                    raise RuntimeError(f"The attribute you want to keep \"{el}\" is not present in the "
-                                       f"\"nb_bins\". This attribute is continuous, you have to specify in how "
-                                       f"how to convert it to a discrete space. See the documentation "
-                                       f"for more information.")
+                    raise RuntimeError(
+                        f'The attribute you want to keep "{el}" is not present in the '
+                        f'"nb_bins". This attribute is continuous, you have to specify in how '
+                        f"how to convert it to a discrete space. See the documentation "
+                        f"for more information."
+                    )
+                nb_redispatch = np.sum(act_sp.gen_redispatchable)
+                nb_renew = np.sum(act_sp.gen_renewable)
                 if el == "redispatch":
-                    self.dict_properties[el] = ([nb_bins[el] if redisp else 1 for redisp in act_sp.gen_redispatchable],
-                                                act_sp.n_gen, self.ATTR_NEEDBINARIZED)
+                    self.dict_properties[el] = (
+                        [nb_bins[el] for _ in range(nb_redispatch)],
+                        nb_redispatch,
+                        self.ATTR_NEEDBINARIZED,
+                    )
                 elif el == "curtail" or el == "curtail_mw":
-                    self.dict_properties[el] = ([nb_bins[el] if renew else 1 for renew in act_sp.gen_renewable],
-                                                act_sp.n_gen, self.ATTR_NEEDBINARIZED)
+                    self.dict_properties[el] = (
+                        [nb_bins[el] for _ in range(nb_renew)],
+                        nb_renew,
+                        self.ATTR_NEEDBINARIZED,
+                    )
                 elif el == "set_storage":
-                    self.dict_properties[el] = ([nb_bins[el] for _ in range(act_sp.n_storage)],
-                                                act_sp.n_gen, self.ATTR_NEEDBINARIZED)
+                    self.dict_properties[el] = (
+                        [nb_bins[el] for _ in range(act_sp.n_storage)],
+                        act_sp.n_storage,
+                        self.ATTR_NEEDBINARIZED,
+                    )
                 else:
-                    raise RuntimeError(f"Unknown attribute \"{el}\"")
+                    raise RuntimeError(f'Unknown attribute "{el}"')
 
         self._dims = None
         self._functs = None  # final functions that is applied to the gym action to map it to a grid2Op action
@@ -232,12 +277,12 @@ class MultiDiscreteActSpace(MultiDiscrete):
 
     @staticmethod
     def _funct_set(vect):
-        # gym encodes: 
+        # gym encodes:
         # for set_bus: 0 -> -1, 1-> 0 (don't change)), 2-> 1, 3 -> 2
         # for set_status: 0 -> -1, 1-> 0 (don't change)), 2-> 1 [3 do not exist for set_line_status !]
         vect -= 1
         return vect
-    
+
     @staticmethod
     def _funct_change(vect):
         # gym encodes 0 -> False, 1 -> True
@@ -271,44 +316,59 @@ class MultiDiscreteActSpace(MultiDiscrete):
             if el in self.dict_properties:
                 nvec_, dim_, type_ = self.dict_properties[el]
                 if type_ == self.ATTR_CHANGE:
-                    # I can convert them directly into discrete attributes because it's a 
+                    # I can convert them directly into discrete attributes because it's a
                     # recognize "change" attribute
                     funct = self._funct_change
                 elif type_ == self.ATTR_SET:
-                    # I can convert them directly into discrete attributes because it's a 
+                    # I can convert them directly into discrete attributes because it's a
                     # recognize "set" attribute
                     funct = self._funct_set
                 elif type_ == self.ATTR_NEEDBINARIZED:
                     # base action was continuous, i need to convert it to discrete action thanks
                     # to "binarization", that is done automatically here
                     from grid2op.gym_compat.box_gym_actspace import BoxGymActSpace
-                    from grid2op.gym_compat.continuous_to_discrete import ContinuousToDiscreteConverter
+                    from grid2op.gym_compat.continuous_to_discrete import (
+                        ContinuousToDiscreteConverter,
+                    )
+
                     if box_space is None:
                         with warnings.catch_warnings():
                             warnings.filterwarnings("ignore")
-                            box_space = BoxGymActSpace(self._act_space,
-                                                       attr_to_keep=["redispatch", "set_storage", "curtail", "curtail_mw"]
-                                                      )
+                            box_space = BoxGymActSpace(
+                                self._act_space,
+                                attr_to_keep=[
+                                    "redispatch",
+                                    "set_storage",
+                                    "curtail",
+                                    "curtail_mw",
+                                ],
+                            )
 
                     if el not in box_space.dict_properties:
-                        raise RuntimeError(f"Impossible to dertmine lowest and maximum value for "
-                                           f"key \"{el}\".")
+                        raise RuntimeError(
+                            f"Impossible to dertmine lowest and maximum value for "
+                            f'key "{el}".'
+                        )
                     low_, high_, shape_, dtype_ = box_space.dict_properties[el]
                     tmp_box = Box(low=low_, high=high_, dtype=dtype_)
-                    tmp_binarizer = ContinuousToDiscreteConverter(init_space=tmp_box,
-                                                                  nb_bins=self._nb_bins[el])
+                    tmp_binarizer = ContinuousToDiscreteConverter(
+                        init_space=tmp_box, nb_bins=self._nb_bins[el]
+                    )
                     self._binarizers[el] = tmp_binarizer
                     funct = tmp_binarizer.gym_to_g2op
                 elif type_ == self.ATTR_NEEDBUILD:
                     # attributes comes from substation manipulation, i need to build the entire space
                     nvec_ = []
                     self._sub_modifiers[el] = []
-                    if el == "sub_set_bus": 
+                    if el == "sub_set_bus":
                         # one action per substations, using "set"
                         for sub_id in range(self._act_space.n_sub):
                             act_this_sub = [self._act_space()]
-                            act_this_sub += self._act_space.get_all_unitary_topologies_set(self._act_space,
-                                                                                           sub_id=sub_id)
+                            act_this_sub += (
+                                self._act_space.get_all_unitary_topologies_set(
+                                    self._act_space, sub_id=sub_id
+                                )
+                            )
                             nvec_.append(len(act_this_sub))
                             self._sub_modifiers[el].append(act_this_sub)
                         funct = self._funct_substations
@@ -316,31 +376,46 @@ class MultiDiscreteActSpace(MultiDiscrete):
                         # one action per substation, using "change"
                         for sub_id in range(self._act_space.n_sub):
                             acts_this_sub = [self._act_space()]
-                            acts_this_sub += self._act_space.get_all_unitary_topologies_change(self._act_space,
-                                                                                               sub_id=sub_id)
+                            acts_this_sub += (
+                                self._act_space.get_all_unitary_topologies_change(
+                                    self._act_space, sub_id=sub_id
+                                )
+                            )
                             nvec_.append(len(acts_this_sub))
                             self._sub_modifiers[el].append(acts_this_sub)
                         funct = self._funct_substations
                     elif el == "one_sub_set":
                         # an action change only one substation, using "set"
-                        self._sub_modifiers[el] = self._act_space.get_all_unitary_topologies_set(self._act_space)
+                        self._sub_modifiers[
+                            el
+                        ] = self._act_space.get_all_unitary_topologies_set(
+                            self._act_space
+                        )
                         funct = self._funct_one_substation
                         nvec_ = [len(self._sub_modifiers[el])]
                     elif el == "one_sub_change":
                         # an action change only one substation, using "change"
-                        self._sub_modifiers[el] = self._act_space.get_all_unitary_topologies_change(self._act_space)
+                        self._sub_modifiers[
+                            el
+                        ] = self._act_space.get_all_unitary_topologies_change(
+                            self._act_space
+                        )
                         funct = self._funct_one_substation
                         nvec_ = [len(self._sub_modifiers[el])]
                     else:
-                        raise RuntimeError(f"Unsupported attribute \"{el}\" when dealing with "
-                                           f"action on substation")
-                    
+                        raise RuntimeError(
+                            f'Unsupported attribute "{el}" when dealing with '
+                            f"action on substation"
+                        )
+
                 else:
                     raise RuntimeError(f"Unknown way to build the action.")
             else:
-                li_keys = '\n\t- '.join(sorted(list(self.dict_properties.keys())))
-                raise RuntimeError(f"Unknown action attributes \"{el}\". Supported attributes are: "
-                                   f"\n\t- {li_keys}")
+                li_keys = "\n\t- ".join(sorted(list(self.dict_properties.keys())))
+                raise RuntimeError(
+                    f'Unknown action attributes "{el}". Supported attributes are: '
+                    f"\n\t- {li_keys}"
+                )
             dim += dim_
             if nvec is not None:
                 nvec += nvec_
@@ -372,7 +447,20 @@ class MultiDiscreteActSpace(MultiDiscrete):
         if type_ == self.ATTR_NEEDBUILD:
             funct(res, attr_nm, vect)
         else:
-            setattr(res, attr_nm, funct(vect))
+            tmp = funct(vect)
+            if attr_nm == "redispatch":
+                gym_act_this_ = np.full(
+                    self._act_space.n_gen, fill_value=np.NaN, dtype=dt_float
+                )
+                gym_act_this_[self._act_space.gen_redispatchable] = tmp
+                tmp = gym_act_this_
+            elif attr_nm == "curtail" or attr_nm == "curtail_mw":
+                gym_act_this_ = np.full(
+                    self._act_space.n_gen, fill_value=np.NaN, dtype=dt_float
+                )
+                gym_act_this_[self._act_space.gen_renewable] = tmp
+                tmp = gym_act_this_
+            setattr(res, attr_nm, tmp)
         return res
 
     def from_gym(self, gym_act):
@@ -394,17 +482,18 @@ class MultiDiscreteActSpace(MultiDiscrete):
         """
         res = self._act_space()
         prev = 0
-        for attr_nm, where_to_put, funct, type_ in \
-            zip(self._attr_to_keep, self._dims, self._functs, self._types):
+        for attr_nm, where_to_put, funct, type_ in zip(
+            self._attr_to_keep, self._dims, self._functs, self._types
+        ):
             if not gym_act.shape or not gym_act.shape[0]:
                 continue
             this_part = 1 * gym_act[prev:where_to_put]
             if attr_nm in self.dict_properties:
                 self._handle_attribute(res, this_part, attr_nm, funct, type_)
             else:
-                raise RuntimeError(f"Unknown attribute \"{attr_nm}\".")
+                raise RuntimeError(f'Unknown attribute "{attr_nm}".')
             prev = where_to_put
-        return res   
-        
+        return res
+
     def close(self):
         pass
